- `flask_embed.py` run with `python flask_embed.py` and open http://127.0.0.1:8000/ in a web browser.
- `flask_gunicorn_embed.py` a UNIX environment is required to run this script.
- `notebook_embed.ipynb` requires [Jupyter Notebook](https://jupyter.org/).
- `standalone_embed.py` run with `python standalone_embed.py`.
On Windows, the `num_procs=4` argument must be removed from the Server initialisation call on line 34.
- `tornado_embed.py` run with `python tornado_embed.py`.
On Windows, the `num_procs=4` argument must be removed from the Server initialisation call on line 47.
